@@ -1,5 +1,5 @@
 package WebService::Google::Client;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # ABSTRACT: Server-side client library for any Google App API. Based on Moose
 
@@ -97,7 +97,7 @@ WebService::Google::Client - Server-side client library for any Google App API.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -121,6 +121,54 @@ To create authorization file with tokens in current folder run I<goauth> CLI too
 
 See unit test in xt folder for more examples
 
+=head1 DESCRIPTION
+
+This module, still undergoing heavy development, provides an OAuth 2.0
+server-side web application flow to all of the Google API services.
+
+=head1 GETTING STARTED
+
+To develop with this module, you must have a user account with Google as well as
+a developer account both of which can be obtained from Google after acceoptance
+of their terms and conditions. Consult Google for more information on
+establishing these accounts.
+
+Next, you will need to register a project with Google using the Google Developer
+Console and create OAuth2 cient ID credentials for the project. This is
+accomplished by first setting up a "consent screen." The consent screen is what
+allows a resource owner (which will be just you, the developer, at first) to
+give your Google project authorization to access their data using Google's API
+calls. This consent screen does not have to be verified since it is not public.
+Simply supply an "Application name" and hit "Save." Once done, finish the
+process by creating an "Other" application type. Finally, you will need to
+enable the various APIs and services you want your module to access on behalf of
+the resource owners. Consult Google's documentation for more detailed
+information on configuring your project and its APIS.
+
+Once your project is set up with the OAuth 2.0 credentials and has APIs enabled,
+you now need to ask the resource owner (in this case you) for permission to
+access their data. This is done by using the C<goauth> utility in the C<bin>
+directory of this module. Before using it, you need to manually configure the
+scopes you will ask permission from the user to access. Unfortunately, these
+scopes are hard coded into this module at the bottom of the
+C<WebService/Google/Client/Server.pm> module in the C<__DATA__>. This will be
+improved in the near future. Add your scopes to the C<scope> key. The scope is
+a URL and are L<listed here|https://developers.google.com/identity/protocols/googlescopes>.
+
+Once the scopes are added, execute the C<bin/goauth> script. It will prompt you
+for the C<client_id> and C<client_secret> both which are available through the
+Google console. Once entered, point your browser to C<127.0.0.1:3001> and click
+on the "Click here to get Mojo tokens" link. Next log in and/or approve the
+request to access your data for the scopes listed. Once the process is complete,
+a C<config.json> file will be generated for you in your directory. This JSON
+file contains the tokens used by this module to make API requests on behalf of
+you, the resource owner.
+
+Once you have verified you have everything working, you can set to work setting
+up a public facing consent screen so C<WebService::Google::Client> can get scope
+authorization from other resource owners and begin making API requests on their
+behalf.
+
 =head1 KEY FEATURES
 
 =over 1
@@ -137,12 +185,6 @@ See unit test in xt folder for more examples
 
 =back
 
-=head1 SEE ALSO
-
-L<API::Google> - my old lib
-
-L<Google::API::Client> - source of inspiration
-
 =head1 SUPPORTED APIs
 
     SERVICE                     VERSIONS                                   DOCUMENTATION
@@ -285,6 +327,31 @@ L<Google::API::Client> - source of inspiration
     youtubeAnalytics            v1, v1beta1, v2                            http://developers.google.com/youtube/analytics/, https://developers.google.com/youtube/analytics
     youtubereporting            v1                                         https://developers.google.com/youtube/reporting/v1/reports/
 
+=head1 BUGS AND LIMITATIONS
+
+On 2018-10-03, this project was forked from the L<Moo::Google> project which
+stagnated and has apparently been abandoned. As designed, this module does not
+function with all possible Google API calls but will work with simpler API
+calls.  However, to our knowledge, all API calls with the exception of batch API
+calls, can be made via the lower level C<api_aquery> method. This is documented
+here:
+
+L<https://www.perlmonks.org/?node_id=1219833>
+
+=head1 CONTRIBUTIONS AND BUG REPORTS
+
+Please visit our L<GitHub project home
+page|https://github.com/sdondley/WevService-Google-Client> to report bugs and
+make contributions.
+
+More thorough documentation on how to contribute is in the works.
+
+=head1 SEE ALSO
+
+L<API::Google> - my old lib
+
+L<Google::API::Client> - source of inspiration
+
 =head1 AUTHOR
 
 Steve Dondley <s@dondley.com>
